const fetchCoCo = require('./utils/coco');
const fetchApiV2 = require('./utils/capi-v2');

const getConcordance = (path) => {
	const options = {
		path: path
	};
	return fetchCoCo(options)
		.then(data => {
			if (data && data.concordances) {
				return data.concordances;
			} else {
				// HACK all concordance data will go into COCO, but not yet completed so using APIV2 as a backup
				return fetchApiV2(options)
					.then(data => {
						if (data && data.concordances) {
							return data.concordances;
						} else {
							return;
						}
					});
			}
		});
};

const tmeToV2 = (id) => {
	const path = `/concordances?authority=http://api.ft.com/system/FT-TME&identifierValue=${id}`;
	return getConcordance(path)
	.then(concordanceData => {
		if (concordanceData) {
			const concordances = concordanceData.filter(concordance => {
				return concordance.identifier.identifierValue === id && concordance.concept && concordance.concept.id;
			});
			if (concordances.length === 0) {
				return;
			}
			return concordances[0].concept.id.substr(concordances[0].concept.id.lastIndexOf('/') + 1);
		}
	});
};

const v2ToTME = (id) => {
	const path = `/concordances?conceptId=http://api.ft.com/things/${id}`;
	return getConcordance(path)
	.then(concordanceData => {
		if (concordanceData) {
			const concordances = concordanceData.filter(concordance => {
				return concordance.identifier.authority === 'http://api.ft.com/system/FT-TME';
			});
			if (concordances.length === 0) {
				return;
			}
			return concordances[0].identifier.identifierValue;
		}
	});
}

const isUuid = (value) => {
	return /^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$/.test(value);
}

module.exports = (opts) => {
	const id = opts.id;
	if (!id) return;
	return isUuid(id) ? v2ToTME(id) : tmeToV2(id);
};
