const expect = require('chai').expect;
const nock = require('nock');
const proxyquire = require('proxyquire');
const sinon = require('sinon');

const err = sinon.stub();

const fetchCoCo = proxyquire('../../src/utils/coco', {
	'@financial-times/n-logger': { default: { warn: err } }
});
const apiResult = {result: 'success'};

describe('Fetch from CoCo', () => {

	beforeEach(() => {
		nock.cleanAll();
	});

	describe('for a 200 response', () => {

		beforeEach(() => {
			nock('https://prod-coco-up-read.ft.com')
				.get('/brands/abcd')
				.times(1)
				.reply(200, apiResult);
		});

		it('returns an object', () => {
			return fetchCoCo({path: '/brands/abcd'})
				.then(res => {
					expect(nock.isDone()).to.be.true;
					expect(res.result).to.equal('success');
				});
		});

	});

	describe('for a 404 response', () => {

		beforeEach(() => {
			nock('https://prod-coco-up-read.ft.com')
				.get('/brands/efgh')
				.times(1)
				.reply(404);
		});

		it('it logs the error', () => {
			return fetchCoCo({path: '/brands/efgh'})
				.then(res => {
					expect(nock.isDone()).to.be.true;
					expect(res).to.be.undefined;
					expect(err.callCount).to.equal(1);
				});
		});
	});

});
